# APQC
Accelerated Probabilistic Quantum Clustering

**TODO:** Add more information in the readme about the algorithm and the usage

## Initial steps
Follow the test_examples


## Mathematical background
There is an open-version of the [paper](1902.05578.pdf) in the main folder.
- [Current version in Knowledge-Based Systems](https://doi.org/10.1016/j.knosys.2020.105567)

- [arXiv preliminar version](https://arxiv.org/abs/1902.05578)